@@ -184,15 +184,23 @@ plot.sjSDMinternalStructure <- function(x,
   internals[[2]] = standardize_df(internals[[2]], negatives)
   plots_internals = list()
   
+  old_par = par(no.readonly = TRUE)
+  on.exit(par(old_par))
+  
   # Code taken from https://github.com/javirudolph/iStructureMetaco/blob/master/InternalStructureMetacommunities_2021_manuscript/Figures.R
   
   
   if(min(internals[[1]][,1:3]) < 0 | min(internals[[2]][,1:3]) < 0) {
     message("Negative partial R-square detected. Negative R-squareds can occur but they cannot be displayed by the ternary plot.")
   }
+  par(mfrow = c(1,2))
   
   for(i in 1:length(internals)) {
     
+    
+
+    
+    
     add_grad = FALSE
     if((i == 1) & !is.null(env_deviance)) add_grad = TRUE
     
@@ -208,67 +216,114 @@ plot.sjSDMinternalStructure <- function(x,
     
     color = if(!negative_r2) {NULL} else {"r2"}
     
-    plt = 
-      ggtern::ggtern(internals[[i]], ggplot2::aes_string(x = "env", z = "spa", y = "codist", size = abs(internals[[i]]$r2), color = color) ) +
-      ggtern::scale_T_continuous(limits=c(0,1),
-                                 breaks=seq(0, 1,by=0.2),
-                                 labels=seq(0,1, by= 0.2)) +
-      ggtern::scale_L_continuous(limits=c(0,1),
-                                 breaks=seq(0, 1,by=0.2),
-                                 labels=seq(0, 1,by=0.2)) +
-      ggtern::scale_R_continuous(limits=c(0,1),
-                                 breaks=seq(0, 1,by=0.2),
-                                 labels=seq(0, 1,by=0.2)) +
-      #ggplot2::scale_size_area( max_size = 3) +
-      ggplot2::labs(title = names(internals)[i],
-                    x = "E",
-                    xarrow = "Environment",
-                    y = "C",
-                    yarrow = "Species associations",
-                    z = "S", 
-                    zarrow = "Space") +
-      ggtern::theme_bw() +
-      ggtern::theme_showarrows() +
-      ggtern::theme_arrowlong() +
-      ggplot2::theme(
-        panel.grid = ggplot2::element_line(color = "darkgrey", size = 0.3),
-        plot.tag = ggplot2::element_text(size = 11),
-        plot.title = ggplot2::element_text(size = 11, hjust = 0.1 , margin = ggplot2::margin(t = 10, b = -20)),
-        tern.axis.arrow = ggplot2::element_line(size = 1),
-        tern.axis.arrow.text = ggplot2::element_text(size = 6),
-        axis.text = ggplot2::element_text(size = 4),
-        axis.title = ggplot2::element_text(size = 6),
-        legend.text = ggplot2::element_text(size = 6),
-        legend.title = ggplot2::element_text(size = 8),
-        strip.text = ggplot2::element_text(size = 8),
-        plot.margin = unit(c(top,1,1,1)*0.2, "cm"),
-        strip.background = ggplot2::element_rect(color = NA),
-      ) +
-      { if(!negative_r2) ggplot2::guides(size = ggplot2::guide_legend(title = expression(R^2), order = 1)) } +
-      { if(!add_grad)ggplot2::geom_point(alpha = 0.7) }+
-      { if(add_grad) ggplot2::geom_point(alpha = 0.7, aes(fill=env_deviance, color = env_deviance)) }+  
-      { if(!negative_r2)  ggplot2::scale_size_continuous(range = c(0.1,5),limits = c(r2min, r2max), breaks = seq(r2min, r2max, length.out=5)) } +
-      { if(negative_r2)   ggplot2::scale_color_gradient2(low = "red", mid = "grey50", high = "black", midpoint = 0, 
-                                                  breaks = c(r2min, 0, r2max), 
-                                                  labels = c(r2min, "0", r2max), 
-                                                  limits = c(r2min, r2max),
-                                                  guide = ggplot2::guide_colorbar(title = expression(R^2))) } +
-      { if(negative_r2)  ggplot2::scale_size_continuous(range = c(0.1,5), 
-                                               breaks =  seq(0, r2max, length.out = 5), guide = "none")  } +
+
+    min_s = c(internals[[i]]$r2) |> abs() |> min()
+    max_s = c(internals[[i]]$r2) |> abs() |> max()
+    labels_sizes = round(seq(min_s, max_s, length.out = 4), 3)
+    sizes_legend = scales::rescale(labels_sizes, to = c(0.2, 2.0) )
+
+    plot(NULL, NULL, xlim = c(0, 1), ylim = c(0, 1), axes=F, xlab ="", ylab = '')
+    
+
+    if(!negative_r2) {
+      points(x = seq(-0.05, 0.25, length.out = 4), y = rep(0.86, 4),cex = sizes_legend, xpd = NA, pch = 16)
+      text(x = seq(-0.05, 0.25, length.out = 4), y = rep(0.852, 4), labels = labels_sizes, xpd = NA, pos = 1, cex = 0.7)
+      text(x = -0.1, y = 0.89, labels = "R\u00B2:", xpd = NA, cex = 0.9)
+      cols = "#000000AA"
+    } else {
+      cols1 =  grDevices::colorRampPalette(c("#FF1010", "#FFA4B5"))(10)
+      cols2 =  grDevices::colorRampPalette(c("grey70", "black"))(10)
+      image(x=seq(-0.05, 0.2, length.out = 20), y=c(0.86, 0.885), z=matrix(seq(-0.05, 0.2, length.out=20), ncol=1),
+            col=c(cols1, cols2), axes=FALSE, xlab="", ylab="", add = TRUE)
+      r2s = internals[[i]]$r2
+      text(x = c(-0.05, 0.075, 0.2), y = rep(0.852, 3), labels = c(min(r2s) |> round(3), 0, max(r2s) |> round(3)), xpd = NA, pos = 1, cex = 0.7)
+      text(x = -0.1, y = 0.89, labels = "R\u00B2:", xpd = NA, cex = 0.9)
+      names(r2s)[r2s<0] = cols1[as.integer(cut(r2s[r2s<0], breaks = 10))]
+      names(r2s)[r2s>0] = cols2[as.integer(cut(r2s[r2s>0], breaks = 10))]
+      cols = names(r2s)
+    }
+    
+    if(add_grad) {
+      br = min(length(unique(env_deviance)), 20)
+      bg = viridis::viridis(br)[cut(env_deviance, breaks = br)]
       
-      { if(add_grad) ggplot2::scale_fill_gradient(low = "white", high = "black", guide = "none") } + 
-      { if(add_grad) ggplot2::scale_color_gradient(low = "white", high = "black", limits = c(0, max(env_deviance))) } +
-      ggplot2::theme(tern.axis.arrow.text = element_text(size = 7),legend.position = "bottom", legend.margin = margin(r = 30), legend.box="vertical") +
-      { if(!add_grad) { if(!negative_r2)  ggplot2::guides(size = ggplot2::guide_legend(title = expression(R^2), order = 1, nrow = 1, label.position = "bottom")) } } +
-      { if( add_grad) ggplot2::guides(size = ggplot2::guide_legend(title = expression(R^2), order = 1, nrow = 1, label.position = "bottom"),
-                                      color = ggplot2::guide_colorbar(title = "Environmental deviation", title.position = "top", order = 2, barheight = 0.5, barwidth = 8)) } 
-    plots_internals[[i]] = plt
-  }
-  
-  ggtern::grid.arrange(plots_internals[[1]], plots_internals[[2]], nrow=1, widths = c(5.0/10, 5/10))
+      image(x=seq(-0.05, 0.2, length.out = 20)+0.8, y=c(0.86, 0.885), z=matrix(seq(-0.05, 0.2, length.out=20), ncol=1),
+            col=viridis::viridis(20), axes=FALSE, xlab="", ylab="", add = TRUE)
+      text(x = c(-0.05, 0.2)+0.8, y = rep(0.852, 2), labels = c(min(env_deviance) |> round(3),max(env_deviance) |> round(3)), xpd = NA, pos = 1, cex = 0.7)
+    } else {
+      bg = "#000000AA"
+    }
+    
+    plot_tern(internals[[i]], cex = scales::rescale(abs(internals[[i]]$r2), to = c(0.4, 2.0), from = c(min_s, max_s) ), col = cols, bg = bg)
+    
+    if(i == 1) {
+      text(x = -0.1, y = 1.0, label = "Sites", font = 2, xpd = NA)
+    } else {
+      text(x = -0.1, y = 1.0, label = "Species", font = 2, xpd = NA)
+    }
+    
+    
+  #   plt = 
+  #     ggtern::ggtern(internals[[i]], ggplot2::aes_string(x = "env", z = "spa", y = "codist", size = abs(internals[[i]]$r2), color = color) ) +
+  #     ggtern::scale_T_continuous(limits=c(0,1),
+  #                                breaks=seq(0, 1,by=0.2),
+  #                                labels=seq(0,1, by= 0.2)) +
+  #     ggtern::scale_L_continuous(limits=c(0,1),
+  #                                breaks=seq(0, 1,by=0.2),
+  #                                labels=seq(0, 1,by=0.2)) +
+  #     ggtern::scale_R_continuous(limits=c(0,1),
+  #                                breaks=seq(0, 1,by=0.2),
+  #                                labels=seq(0, 1,by=0.2)) +
+  #     #ggplot2::scale_size_area( max_size = 3) +
+  #     ggplot2::labs(title = names(internals)[i],
+  #                   x = "E",
+  #                   xarrow = "Environment",
+  #                   y = "C",
+  #                   yarrow = "Species associations",
+  #                   z = "S", 
+  #                   zarrow = "Space") +
+  #     ggtern::theme_bw() +
+  #     ggtern::theme_showarrows() +
+  #     ggtern::theme_arrowlong() +
+  #     ggplot2::theme(
+  #       panel.grid = ggplot2::element_line(color = "darkgrey", size = 0.3),
+  #       plot.tag = ggplot2::element_text(size = 11),
+  #       plot.title = ggplot2::element_text(size = 11, hjust = 0.1 , margin = ggplot2::margin(t = 10, b = -20)),
+  #       tern.axis.arrow = ggplot2::element_line(size = 1),
+  #       tern.axis.arrow.text = ggplot2::element_text(size = 6),
+  #       axis.text = ggplot2::element_text(size = 4),
+  #       axis.title = ggplot2::element_text(size = 6),
+  #       legend.text = ggplot2::element_text(size = 6),
+  #       legend.title = ggplot2::element_text(size = 8),
+  #       strip.text = ggplot2::element_text(size = 8),
+  #       plot.margin = unit(c(top,1,1,1)*0.2, "cm"),
+  #       strip.background = ggplot2::element_rect(color = NA),
+  #     ) +
+  #     { if(!negative_r2) ggplot2::guides(size = ggplot2::guide_legend(title = expression(R^2), order = 1)) } +
+  #     { if(!add_grad)ggplot2::geom_point(alpha = 0.7) }+
+  #     { if(add_grad) ggplot2::geom_point(alpha = 0.7, aes(fill=env_deviance, color = env_deviance)) }+  
+  #     { if(!negative_r2)  ggplot2::scale_size_continuous(range = c(0.1,5),limits = c(r2min, r2max), breaks = seq(r2min, r2max, length.out=5)) } +
+  #     { if(negative_r2)   ggplot2::scale_color_gradient2(low = "red", mid = "grey50", high = "black", midpoint = 0, 
+  #                                                 breaks = c(r2min, 0, r2max), 
+  #                                                 labels = c(r2min, "0", r2max), 
+  #                                                 limits = c(r2min, r2max),
+  #                                                 guide = ggplot2::guide_colorbar(title = expression(R^2))) } +
+  #     { if(negative_r2)  ggplot2::scale_size_continuous(range = c(0.1,5), 
+  #                                              breaks =  seq(0, r2max, length.out = 5), guide = "none")  } +
+  #     
+  #     { if(add_grad) ggplot2::scale_fill_gradient(low = "white", high = "black", guide = "none") } + 
+  #     { if(add_grad) ggplot2::scale_color_gradient(low = "white", high = "black", limits = c(0, max(env_deviance))) } +
+  #     ggplot2::theme(tern.axis.arrow.text = element_text(size = 7),legend.position = "bottom", legend.margin = margin(r = 30), legend.box="vertical") +
+  #     { if(!add_grad) { if(!negative_r2)  ggplot2::guides(size = ggplot2::guide_legend(title = expression(R^2), order = 1, nrow = 1, label.position = "bottom")) } } +
+  #     { if( add_grad) ggplot2::guides(size = ggplot2::guide_legend(title = expression(R^2), order = 1, nrow = 1, label.position = "bottom"),
+  #                                     color = ggplot2::guide_colorbar(title = "Environmental deviation", title.position = "top", order = 2, barheight = 0.5, barwidth = 8)) } 
+  #   plots_internals[[i]] = plt
+   }
+  # 
+  # ggtern::grid.arrange(plots_internals[[1]], plots_internals[[2]], nrow=1, widths = c(5.0/10, 5/10))
   
   out = list()
-  out$plots = plots_internals
+  #out$plots = plots_internals
   return(invisible(out))
 }
 
@@ -477,3 +532,63 @@ get_eigen = function(X, double_center = TRUE, full = FALSE) {
   }
 }
 
+
+
+
+
+
+
+
+
+
+rad2deg <- function(rad) {(rad * 180) / (pi)}
+deg2rad <- function(deg) {(deg * pi) / (180)}
+get_coords = function(X) {
+  x_w = X[1] + sin(deg2rad(30))*X[2]
+  y_w = cos(deg2rad(30))*X[2]
+  return(c(x_w, y_w))
+}
+
+
+
+plot_line = function(X, Y, arrow= FALSE,...) {
+  Xc = get_coords(X)
+  Yc = get_coords(Y)
+  
+  if(arrow) {
+    arrows(Xc[1], Xc[2], Yc[1], Yc[2],...)
+  } else {
+    segments(Xc[1], Xc[2], Yc[1], Yc[2],...)
+  }
+}
+plot_tern = function(data1, length = 0.12, col = "black", bg = NULL, cex = 1.0) {
+  segments(0,0,1,0)
+  segments(0, 0.0, 0.5, 0.8660254)
+  segments(1,0,0.5, 0.8660254)
+  for(i in seq(0.2, 0.8, length.out = 4)) {
+    plot_line(c(1-i, 0.0, i), c(0.0, 1-i, i), col = "lightgrey")
+    plot_line(c(1-i, i, 0.0), c(1-i, 0.0, i), col = "lightgrey")
+    plot_line(c(0, i, 1-i), c(1-i, i, 0), col = "lightgrey")
+    
+    text(get_coords(c(1-i, 0.0, i))[1], get_coords(c(1-i, 0.0, i))[2]-0.03, labels = 1-i, srt = 60, xpd = NA)
+    text(get_coords(c(1-i, i, 0.0))[1]+0.05, get_coords(c(1-i, i, 0.0))[2], labels = i, xpd = NA)
+    text(get_coords(c(0, i, 1-i))[1]-0.03, get_coords(c(0, i, 1-i))[2]+0.03, labels = 1-i, xpd = NA, srt  = -50)
+  }
+  #arrows(0.2,-0.05,0.8,-0.05, xpd = NA,length = 0.1)
+  text(1, y = -0.02, pos = 1, xpd = NA, label = "Space")
+  text(-0.1, y = -0.02, pos = 1, xpd = NA, label = "Environment")
+  text(0.5, y = 0.9, pos = 3, xpd = NA, label = "Species associations")
+  
+
+  
+  data1[,1:3] = data1[,1:3]/rowSums(data1[,1:3])
+  if(length(col) == 1) col = rep(col, nrow(data1))
+  if(length(cex) == 1) cex = rep(cex, nrow(data1))
+  if(is.null(bg)) bg = col
+  if(length(bg) == 1) bg = rep(bg, nrow(data1))
+  for(i in 1:nrow(data1)) {
+    coords = get_coords(unlist(data1[i,c(2, 3, 1)]))
+    points(x = coords[1], y = coords[2], col = col[i], bg = bg[i], cex = cex[i], pch = 21)
+  }
+}
+
