@@ -114,7 +114,7 @@ print.linear = function(x, ...) {
 #' @example /inst/examples/sjSDM-example.R
 #' @import checkmate
 #' @export
-DNN = function(data = NULL, formula = NULL, hidden = c(10L, 10L, 10L), activation = "relu", bias = TRUE, lambda = 0.0, alpha = 0.5, dropout = 0.0) {
+DNN = function(data = NULL, formula = NULL, hidden = c(10L, 10L, 10L), activation = "selu", bias = TRUE, lambda = 0.0, alpha = 0.5, dropout = 0.0) {
   
   assert(checkMatrix(data), checkDataFrame(data))
   qassert(hidden, "X+[1,)")
@@ -290,7 +290,7 @@ sjSDMControl = function(optimizer = RMSprop(),
 
 check_family = function(family){
   out = list()
-  if(!family$family %in% c("binomial", "poisson", "gaussian")) stop(paste0(family$family, " ->  not supported"), call. = FALSE)
+  if(!family$family %in% c("binomial", "poisson", "gaussian", "nbinom")) stop(paste0(family$family, " ->  not supported"), call. = FALSE)
   
   if(family$family == "binomial"){
     if(!family$link %in% c("logit", "probit")){
@@ -305,6 +305,13 @@ check_family = function(family){
     out$link = "count"
   }
   
+  if(family$family == "nbinom"){
+    if(!family$link %in% c("log")){
+      stop(paste0(family$link, " ->  not supported"), call. = FALSE)
+    }
+    out$link = "nbinom"
+  }
+  
   if(family$family == "gaussian"){
     if(!family$link %in% c("identity")){
       stop(paste0(family$link, " ->  not supported"), call. = FALSE)
